Glossary

batch

All plates used in one iteration of an ONTOLOGY workflow.

plate

A PCR plate with wells containing DNA samples. Prepared prior to sequencing in both DNA Barcoding and Metabarcoding workflows.

run

The set of specimens or samples that are analyzed on a single flow cell.

UMI

A distinct short DNA sequence used as part of a schema for distinguishing samples following sequencing.

BIN

Barcode Index Number - The taxonomic unit employed by BOLD Systems using DNA barcode sequence data. Often corresponds to species, but may not align with species concept in some cases.

ASV

Amplified Sequence Variant - A working definition for a taxon from sequence data that groups near-exact sequences (i.e., a group of sequences which diverge by one to few base pairs, or not at all).

OTU

Operational Taxonomic Unit - A working definition for a taxon from sequence data that groups sequences with high similarity, but not as high as ASV (i.e., a group of sequences with ~97% sequence similarity).

hit-picking

Re-sequencing and re-assessing samples from specific wells.